@@ -449,33 +449,40 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 			rt = 0;
 			size = atoi(rh->rq_fv_clt);
 
-			if (blen > 0) {
-				r = http_body_comp(body, blen, blen, size);
-				if (r > 0)
-					sys_write(fds1[1], body, r);
-				else
-					sys_write(fds1[1], body, blen);
-			}
-
-			if (blen == 0 || r == 0) {
-				rt += blen;
-				for (;;) {
-					if (c[sfd].x_ssl)
-						rp = sys_read_ssl(c[sfd].ssl,
-						    buf, sizeof(buf));
+			if (size > 0) {
+				if (blen > 0) {
+					r = http_body_comp(body, blen, blen,
+					    size);
+					if (r > 0)
+						sys_write(fds1[1], body, r);
 					else
-						rp = sys_read(sfd,
-						    buf, sizeof(buf));
+						sys_write(fds1[1], body, blen);
+				}
 
-					if (rp < 1)
-						break;
-					rt += rp;
-					r = http_body_comp(buf, rp, rt, size);
-					if (r > 0) {
-						sys_write(fds1[1], buf, r);
-						break;
-					} else
-						sys_write(fds1[1], buf, rp);
+				if (blen == 0 || r == 0) {
+					rt += blen;
+					for (;;) {
+						if (c[sfd].x_ssl)
+							rp = sys_read_ssl(
+							    c[sfd].ssl, buf,
+							    sizeof(buf));
+						else
+							rp = sys_read(sfd,
+							    buf, sizeof(buf));
+
+						if (rp < 1)
+							break;
+						rt += rp;
+						r = http_body_comp(buf, rp, rt,
+						    size);
+						if (r > 0) {
+							sys_write(fds1[1], buf,
+							    r);
+							break;
+						} else
+							sys_write(fds1[1], buf,
+							    rp);
+					}
 				}
 			}
 		}
